@@ -1,5 +1,9 @@
 cvFolds <-
 function(data, nfolds=10, stratify=T) {
+    if(nfolds == -1) {
+        stratify = F
+        nfolds = nrow(data$data)
+    }
     tmp = ddply(data$data, if(stratify) { "best" }, function(x) {
         n = nrow(x)
         x$fold = rep(1:nfolds, length.out = n)[sample(n, n)]
